\begin{code}
module BasicMoves where
import PIL
import DT
\end{code}

Changes of coordinates in Dehn-Thurston coordinates when we perform
one of the two basic moves, exchanging one of the curves in the pants
decomposition for another that intersects it a minimal number of
times.

\begin{code}
firstTrans :: Coord -> DTAnnulus -> (DTAnnulus, Coord)
firstTrans ma b =
    let mb = m b ; tb = t b
	mc = abs tb//2 + ll ma mb mb
	tc = -2*sign tb * (mb - ll ma mc mc)
	dta = -ma//2 + sign tb*((abs tb//2) `dn` (ma//2) `dn` mb)
    in (DTAnnulus { m = mc, t = tc }, dta)
\end{code}

\begin{code}
secondTrans :: Neighbors -> DTAnnulus ->
	         (DTAnnulus, Neighbors)
secondTrans (ma,mb,mc,md) e =
    let me = m e ; te = t e
	f x y z = 0 `up` (y - x) `up` (z - x) `up` ((y+z-x)//2)
	m1 = (ma + mc - me) `up` (mb + md - me)
	m2 = (abs te + f me ma mb + f me mc md)
	mf = m1 `up` m2
	tf = if m1 > m2
	     then -te
	     else -sign te*(me - f mf mb mc - f mf md ma)

	la = lk ma me mb ; lb = lk mb me ma
	lc = lk mc me md ; ld = lk md me mc
	dta = sign te * lk (abs te) la ld
	dtb = sign te * lk (abs te) lb lc
	dtc = sign te * lk (abs te) lc lb
	dtd = sign te * lk (abs te) ld la
    in (DTAnnulus { m = mf, t = tf }, (dta, dtb, dtc, dtd))
\end{code}

Copyright 2002, 2004 Dylan Thurston.

This file is part of the genus2fiber program for computing what
percentage of tunnel-number one 3-manifolds fiber.  It can be
redistributed and/or modified under the terms of the GNU General
Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.
